<?php
/**
 * Plugin Filehtml (addon for plugin Adm_redacteurs)
 * Version  : 1.6 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00 et Adm_redacteurs v6.14+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

class Filehtml_controller extends Controller
{
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_params = array();        // Données récupérés par post ou get
 
    protected $_doc_infos = array('name' => 'filehtml', 'type' => 'filehtml'); // Tableau contenant les informations du document (nom, type)
    protected $_addon = 'filehtml'; // Nom de l'addon
    protected $_file_data = array();
    protected $_filehtml_contents = array('head' => '', 'body' => '');
    protected $_file_base_path = ''; // Chemin de base du fichier

    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */
    function __construct()
    {
        parent :: __construct();

        $this -> load_helper('var_helper');
        $this -> load_helper('date_helper');
        $this -> load_helper('private_groups_helper');
        
        $this -> load_addon_model('filehtml', 'filehtml_ids_model');       
        $this -> load_addon_model('filehtml', 'filehtml_params_model');

        $this -> load_addon_lang('filehtml');
        $this -> load_addon_config('filehtml');
        
        $this -> _lang = $this -> get_lang();
        $this -> _config = $this -> get_config();       
        $this -> _params = $this -> _set_params();
        $this -> _file_data = $this -> _get_file_data($this -> _params['docid']);
        $this -> _file_base_path = $this -> _get_file_base_path($this -> _file_data['link']);       
        $this -> _filehtml_contents = $this -> _get_page_contents($this -> _file_data);
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */
    public function index()
    {
//       print_r($this -> _config); // Debug
        $data = array(
            'lang' => $this -> _lang,
            'config' => $this -> _config,
            'is_allowed_for_publication' => $this -> _is_allowed_for_publication(),
            'contents' => $this -> _filehtml_contents,
            'file_data' => $this -> _file_data,
            'author' => $this -> _get_author(),
            'nb_views' => $this -> _get_nb_views(),
        );
      
        $this -> render(str_replace(ADMR_PUBLIC_ROOT_PATH, '..', FILEHTML_VIEWS_PATH).'/filehtml', $data);
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le nom de l'auteur
     *
     * @return boolean
     */
    protected function _get_author()
    {
        $this -> load_model('writer_model');            
        
        $author = $this -> writer_model -> get_by_id($this -> _file_data['author_id']);
       
        return empty($author) ? $this -> _config['user'][0] : $author['name'];
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le nombre de vue de l'article
     *
     * @return boolean
     */
    protected function _get_nb_views()
    {
        $this -> load_addon_model('filehtml', 'filehtml_counters_model', $this -> _file_data['id']);            
        
        $this -> filehtml_counters_model -> increase_counter();
       
        return $this -> filehtml_counters_model -> get_counter();
    }

	// --------------------------------------------------------------------

    /**
     * Vérifie si le document est autorisé à être publié 
     *
     * @return boolean
     */
    protected function _is_allowed_for_publication()
    {
        if ($this -> _file_data['status'] == 'a'
            && Date_helper :: is_valid_date_for_publication($this -> _file_data['createdate'])
            && Private_groups_helper :: is_allowed_for_access($this -> _file_data['group']))
        {
            return TRUE;    
        }           
        
        return FALSE;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie les informations du document
     *
     * @param integer Identifiant du document
     * @return array
     */
    protected function _get_file_data($file_id)
    {
        $file_data = array_merge(
            $this -> filehtml_params_model -> read($file_id),
            $this -> filehtml_ids_model -> get_by_id($file_id)            
        );
        
        $lang_index = ($this -> _config['lang'][1] === ADMR_LNG) ? 2 : 1;     

        foreach(array('title', 'link', 'iframe', 'iframe_height', 'previous_page_label', 'previous_page_uri', 'next_page_label', 'next_page_uri') as $item) {
            $file_data[$item] = $file_data[$item.$lang_index];
        }

        foreach(array('contents_before', 'contents_after') as $item) {
            $file_data[$item] = Var_helper :: convert_relative_path_to_absolute($file_data[$item.$lang_index]);
        }
        
        return $file_data;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le chemin de base du fichier
     *
     * @param string Chemin du fichier
     * @return string Chemin de base du fichier
     */
    protected function _get_file_base_path($file_path)
    {     
        return CHEMIN.dirname($file_path).'/';
    }

	// --------------------------------------------------------------------

    /**
     * Affiche ou renvoie le contenu de la page html
     *
     * @param array Données du fichier
     * @return array Tableau contenant le contenu de la page sous la forme array('head' => , 'body' => )
     */
    protected function _get_page_contents($file)
    {
        $page = array('head' => '', 'body' => '');
        
        if (empty($file['iframe'])) {    
            $file_contents = $this -> _get_file_contents($file['link']); 
                      
            if (!empty($file_contents)) {    
                $page['head']  = $this -> _get_page_head_contents($file_contents);
                $page['body']  = $this -> _get_page_body_contents($file_contents);           
            }
        }
   
        return $page;
    }

	// --------------------------------------------------------------------

    /**
     * Renvoie le contenu du fichier
     *
     * @param string Chemin du fichier
     * @return string Contenu du fichier
     */
    protected function _get_file_contents($file_path)
    {     
        return is_file(CHEMIN.$file_path) ? file_get_contents(CHEMIN.$file_path) : '';
    }

	// --------------------------------------------------------------------

    /**
     * Affiche ou renvoie le contenu du titre de la page html
     *
     * @param string Contenu du fichier
     * @return string Titre de la page
     */
    public function _get_page_title_contents($file_contents)
    {
        preg_match("/<title>(.*)<\/title>/isU", $file_contents, $page_title);
         
        return !empty($page_title[1]) ? $page_title[1] : '';
    }

	// --------------------------------------------------------------------

    /**
     * Affiche ou renvoie le contenu de l'entête de la page html
     *
     * @param string Contenu du fichier
     * @return array Tableau contenant le contenu de la page sous la forme array('head' => , 'body' => )
     */
    public function _get_page_body_contents($file_contents)
    {
        preg_match("/<body[^>]*>(.*)<\/body>/isU", $file_contents, $page_body);
		$page_body[1] = preg_replace_callback("` src=([\"\']?)([^\"\'> ]+)([\"\'> ])`isU", array($this, '_convert_img_path'), $page_body[1]);
         
        return $page_body[1];
    }

	// --------------------------------------------------------------------

    /**
     * Convertit les chemins des images dans le contenu du fichier (fonction de callback)
     *
     * @param array Tableau contenant les sélections de l'expression régulière
     * @return string Chaine traitée
     */
	private function _convert_img_path($matches)
    {		
        $url = (preg_match("`^(http|https|ftp)\:\/\/`isU", $matches[2]))? $matches[2] : $this -> _file_base_path.$matches[2];
		$matches[0] = ' src='.$matches[1].$url.$matches[3];
		
        return $matches[0];
	}

	// --------------------------------------------------------------------

    /**
     * Affiche ou renvoie le contenu de l'entête de la page html
     *
     * @param string Contenu du fichier
     * @return string Contenu de l'entête de la page html
     */
    public function _get_page_head_contents($file_contents)
    {
		preg_match("/<head>(.*)<\/head>/isU", $file_contents, $page_head);
		$page_head[1] = preg_replace("`<title>.*<\/title>`isU", '', $page_head[1]);
		$page_head[1] = preg_replace("`<meta[^>]+>`isU", '', $page_head[1]);		
		$page_head[1] = preg_replace_callback("`<style([^>]*)>(.*)</style>`isU", array($this, '_clean_file_style_css'), $page_head[1]);		
		$page_head[1] = preg_replace_callback("` (src|href)=([\"\']?)([^\"\'> ]+)([\"\'> ])`isU", array($this, '_convert_file_path'), $page_head[1]);
        
        return $page_head[1];
    }

	// --------------------------------------------------------------------

    /**
     * Nettoie les instructions css du fichier (fonction de callback)
     *
     * @param array Tableau contenant les sélections de l'expression régulière
     * @return string Chaine traitée
     */	
    private function _clean_file_style_css($matches)
    {
		$matches[2] = preg_replace("`body\s*\{([^}]+)\}`isU", '', $matches[2]);
		$matches[2] = preg_replace("`\n\s*p\s*\{[^}]+\}`isU", '', $matches[2]);
		$matches[2] = preg_replace("`table,div,span,td\s*\{[^}]+\}`isU", '', $matches[2]);
		$matches[2] = preg_replace("`a(:visited)?(:hover)?\s*\{[^}]+\}`is", '', $matches[2]);
		$matches[0] = '<style'.$matches[1].'>'.$matches[2].'</style>'; 
	 	
         return $matches[0];
    }

	// --------------------------------------------------------------------

    /**
     * Convertit les chemins des fichiers dans le contenu du fichier (fonction de callback)
     *
     * @param array Tableau contenant les sélections de l'expression régulière
     * @return string Chaine traitée
     */	
    private function _convert_file_path($matches)
    {
		$url = (preg_match("`^(http|https|ftp)\:\/\/`isU", $matches[3]))? $matches[3] : $this -> _file_base_path.$matches[3];
		$matches[0] = ' '.$matches[1].'='.$matches[2].$url.$matches[4];
		
        return $matches[0];
	}

	// --------------------------------------------------------------------

    /**
     * Affiche ou renvoie le contenu de la vue
     *
     * @param string Nom du fichier de la vue
     * @param array Données à faire passer à la vue
     * @param boolean Renvoie le contenu (TRUE) ou affiche (FALSE) de la vue
     * @return string|void
     */
    public function render_page($filename, $data = array(), $return = FALSE)
    {
        $this -> page_helper -> set_page_layout('public_layout');
        
        $this -> page_helper -> render_page($filename, $data, $return);
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        $parent_addons = $this -> _filehtml_contents['head'];
                
        $js = '';         
        $js .= '<script type="text/javascript" src="'.FILEHTML_JS_PATH.'/filehtml.js"></script>'."\n";

        $css = '';
        $css .= '<link rel="stylesheet" type="text/css" media="screen,print" href="'.FILEHTML_CSS_PATH.'/filehtml.css" />'."\n";

        return $css.$js.$parent_addons;        
    }

	// --------------------------------------------------------------------

	/**
	 * définit et renvoie le titre dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_title_page()
    {
        return !empty($this -> _file_data['id']) ? $this -> _file_data['title'] : $this -> _lang['errors_msg']['error_404'];        
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le mode d'affichage des boites latérales selon le choix sélectionné dans le document
     *
     * @return string
     */
    public function set_sidebars_display_mode()
    {
        $sidebars_display_mode = $this -> _file_data['sidebars'];
/*               
        $this -> load_addon_model('filehtml', 'filehtml_menuitems_model', $this -> _file_data['id']);            
        
        $filehtml_menuitems = $this -> filehtml_menuitems_model -> get(array('id_filehtml' => $this -> _file_data['id']));
       
        if (!empty($filehtml_menuitems)) {
            $filehtml_menuitem = array_pop($filehtml_menuitems);
            
            // Récupération des données de l'item de menu associé au document
            $this -> load_model('menuitems_model');           
            $menuitem = $this -> menuitems_model -> read($filehtml_menuitem['id_menuitem']); 
            //
            
            $sidebars_display_mode = $menuitem['sidebars'];
        }
*/        
        return $sidebars_display_mode;
    }

	// --------------------------------------------------------------------

    /**
     * Définit et renvoie le chemin de l'icone du document
     *
     * @return string Chemin relatif de l'icone
     */
    public function set_icon_page()
    {
        return $this -> _file_data['icon'];
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit les variables utilisées dans la page 
     * 
     * @access protected
	 * @return void
	 */	
    protected function _set_params()
    {
        return $this -> _params = array(
            'docid'     => Var_helper :: import('pg', '', NULL, array('trim'), array(array('Var_helper', 'is_digit'))),
        );
    }
	
} //End of Class