<?php
/**
 * Plugin Filehtml (addon for plugin Adm_redacteurs)
 * Version  : 1.6 (2021/01/03)
 * Compatibility : Guppy v5.x et v6.00.00 et Adm_redacteurs v6.14+
 * Author   : jérôme CROUX (jchouix)
 * Web site : http://lebrikabrak.info/
 * E-mail   : lebrikabrak@free.fr
 * Licence  : GNU Lesser General Public License
 */

defined('ADMR_DIRNAME') OR exit('No direct script access allowed');

require_once ADMR_HELPERS_PATH.'/add_menuitems_helper.php';

class Add_filehtml_menuitems_helper extends Add_menuitems_helper
{
    /*
    |--------------------------------------------------------------------------
    | Properties
    |--------------------------------------------------------------------------
    */
    protected $CI;                       // object global
    protected $_lang = array();          // Données de langue
    protected $_config = array();        // Données de configuration
    protected $_record_id = 0;           // Identifiant de l'enregistrement
    protected $_record_data = array();   // Tableau contenant les données de l'enregistrement
    protected $_form_params = array();   // Tableau contenant les données de l'enregistrement postées dans le formulaire
 	protected $_form_errors = array();	 // Tableau contenant les messages d'erreur dans le formulaire
    protected $_form_validation = FALSE; // Validation du formulaire (TRUE ou FALSE)  

    protected $_writer_rights = array(); // Droits du rédacteur
    
    /*
    |--------------------------------------------------------------------------
    | Constructor
    |--------------------------------------------------------------------------
    */    
    function __construct($writer_rights = array())
    {        
        $this -> _writer_rights = $writer_rights;        
        
        $this -> CI =& Controller :: get_instance();
        
        $this -> CI -> load_model('menuitems_model');
        $this -> CI -> menuitems_model -> set_internal_doc_paths(array('filehtml' => FILEHTML_PUBLIC_FILE_PATH));  // Nécessaire pour la vérification de la validité du lien interne      
       
        $this -> CI -> load_addon_helper('filehtml', 'plugin_menu_for_filehtml_helper');
        $this -> CI -> load_addon_helper('filehtml', 'filehtml_infos_helper');

        $this -> CI -> load_addon_model('filehtml', 'filehtml_params_model');
        $this -> CI -> load_addon_model('filehtml', 'filehtml_ids_model');
        $this -> CI -> load_addon_model('filehtml', 'filehtml_menuitems_model');

//        $this -> CI -> load_addon_model('filehtml', 'writer_filehtml_model', array('id' => $this -> _writer_rights['id']));
        
        $this -> CI -> load_addon_lang('filehtml');
        $this -> CI -> load_addon_config('filehtml');
        
        $this -> _lang = $this -> CI -> get_lang();
        $this -> _config = $this -> CI -> get_config();
        
        parent :: __construct($writer_rights);      
    }

    /*
    |--------------------------------------------------------------------------
    | Methods
    |--------------------------------------------------------------------------
    */    

    /**
	 * Index
     * 
	 * @access public
     * @return void
	 */	
    public function index()
    {
        parent :: index();
    }

	// --------------------------------------------------------------------

    /*
     * Définit et renvoie le titre de la page 
     *
     * @param array Données à faire passer à la vue
     * @return void
     */        
    public function set_title_page()
    {
        return parent :: set_title_page();
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie la description de la page ainsi que les recommendations
     * 
	 * @return string infos de la page
	 */	
    public function set_infos_page_content()
    {		
        return parent :: set_infos_page_content();
    }

	// --------------------------------------------------------------------

    /*
     * Définit le contenu du menu qui est affiché dans le bandeau en haut de la page
     *
     * @return array Tableau contenant les items du menu (vide par défaut)
     */
    public function set_menu_plugin_items()
    {
        if (ADMR_IS_ADMIN) {
            return Plugin_menu_for_filehtml_helper :: set_admin_items('filehtml', $this -> _lang, $this -> _config, $this -> _writer_rights);
        } else {
            return Plugin_menu_for_filehtml_helper :: set_public_items('filehtml', $this -> _lang, $this -> _config, $this -> _writer_rights);
        }
    }

	// --------------------------------------------------------------------

    /**
     * Définit le contenu des informations du plugin qui sont affichées en bas de la page
     *
     * @return array Tableau contenant les informations du plugin sous la forme array('version' => , 'licence' => )
     */
    public function set_infos_plugin()
    {
        return Filehtml_infos_helper :: set_plugin_infos($this -> _lang);
    }
    
	// --------------------------------------------------------------------

	/**
	 * définit et renvoie les ajouts (js et css) dans l'entête de la page
     * 
     * @access public
	 * @return string Chaine html contenant les ajouts js et css
	 */	
    public function set_header_addons()
    {
        return parent :: set_header_addons();
    }

	// --------------------------------------------------------------------

    /**
	 * Ajoute des données supplémentaires
     * 
	 * @access protected
     * @return array
	 */	
    protected function _add_more_data_for_add_record_view()
    {        
        return array_merge(
            parent :: _add_more_data_for_add_record_view(), 
            array(
                'url_external_allowed' => FALSE, // Autorisation ou non d'insérer des url externes
                'sidebars_display_mode_allowed' => FALSE // Autorisation ou non de choisir le mode d'affichage des barres latérales
            )
        );
    }

	// --------------------------------------------------------------------

	/**
	 * retourne la liste des documents du rédacteur
	 *
	 * @access	protected
	 * @return	array sous la forme array(path => array())
	 */
    protected function _get_internal_docs()
    {
        $docs = array();
        
        $docs = array(
            FILEHTML_PUBLIC_FILE_PATH => $this -> _get_data_docs()
        );
               
        return $docs;
    }

	// --------------------------------------------------------------------
    
    /**
	 * Récupère et renvoie les données des documents
     * 
	 * @access protected
     * @param integer Id de l'enregistrement
     * @return array Données enregistrées du document
	 */    
    protected function _get_data_docs()
    {
        $docs = $this -> CI -> filehtml_ids_model -> get(array('author_id' => $this -> _writer_rights['id'], 'status' => array('a', 'i')));
        
        foreach($docs as $doc_id => $doc_data) {
            $docs[$doc_id] = array_merge($docs[$doc_id], $this -> CI -> filehtml_params_model -> read($doc_id));
        }       
        
        return $docs;
    }

	// --------------------------------------------------------------------

    /**
	 * Crée un nouvel enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return integer Identifiant de l'enregistrement créé
	 */
    protected function _insert_record($record)
    {
        $record['id'] = parent :: _insert_record($record);
        
        $this -> CI -> filehtml_menuitems_model -> insert(
            array(
                'id_menuitem' => $record['id'],
                'id_filehtml' => $this -> CI -> menuitems_model -> extract_doc_id_from_item_url($record['internal_link'])
            )
        );
        
        return $record['id'];
    }
    
	// --------------------------------------------------------------------

    /**
	 * Met à jours les données de l'enregistrement dans la base de donnée
     * 
	 * @access protected
     * @param array Tableau contenant les données de l'enregistrement
     * @return void
	 */
    protected function _update_record($record)
    {
        parent :: _update_record($record);

        $this -> CI -> filehtml_menuitems_model -> update(
            array(
                'id_menuitem' => $record['id'],
                'id_filehtml' => $this -> CI -> menuitems_model -> extract_doc_id_from_item_url($record['internal_link'])
            )
        );        
    
        return TRUE;    
    }

	// --------------------------------------------------------------------

    /**
	 * Vérifie la validité d'accès au document par le rédacteur
     * 
	 * @access public
     * @param integer Identifiant du document
     * @return void
	 */
    protected function _is_doc_allowed($doc_id)
    {   
        if (empty($doc_id) && !empty($this -> _writer_rights['filehtml_menuitems_add'])) { // Ajout d'un nouveau document
            return TRUE;
        }
        else {  // Edition d'un document
//            $doc = $this -> CI -> writer_filehtml_model -> get_by_id($doc_id);
            $doc = $this -> CI -> writer_docs_model -> get(array('id' => $doc_id, 'type' => TYP_OPTMENU));

            if (!empty($doc) && !empty($this -> _writer_rights['filehtml_menuitems_edit'])) {
                return TRUE;
            }   
        }

        return FALSE;   
    }

	// --------------------------------------------------------------------

 } // End of class